@@ -13,11 +13,11 @@ PGObject::Simple::Role - Moo/Moose mappers for minimalist PGObject framework
 
 =head1 VERSION
 
-Version 1.11.0
+Version 1.13.0
 
 =cut
 
-our $VERSION = '1.11.0';
+our $VERSION = '1.13.0';
 
 
 =head1 SYNOPSIS
@@ -169,10 +169,7 @@ sub _get_dbh {
 
 =head2 call_procedure
 
-Identical interface to PGObject::Simple->call_procedure.
-
-This can be used on objects or on the packages themselves.  I.e.  
-mypackage->call_procedure() and $myobject->call_procedure() both work.
+Identical to PGObject::Simple::call_procedure
 
 =cut
 
@@ -194,6 +191,11 @@ sub call_procedure {
                  unless defined $args{funcschema} or ref $self;
     }
     my @rows = $obj->call_procedure(%args);
+    for my $row (@rows){
+        for (keys %$row){
+            delete $row->{$_} unless defined $row->{$_};
+        }
+    }
     return @rows if wantarray;
     return shift @rows;
 }
@@ -231,11 +233,10 @@ sub call_dbmethod {
         my $argname = $_->{name};
         my $db_arg;
         $argname =~ s/^in_//;
-        eval { $db_arg = $self->can($argname)->($self) } if ref $self;
-        $db_arg = $args{args}->{$argname} if $args{args}->{$argname};
-        $db_arg = $db_arg->to_db if eval {$db_arg->can('to_db')};
-        $db_arg = { type => 'bytea', value => $db_arg} if $_->{type} eq 'bytea';
-
+        local $@;
+        eval { $db_arg = $self->can($argname)->($self) }
+            if ref $self and $argname;
+        $db_arg = $args{args}->{$argname} if exists $args{args}->{$argname};
         $db_arg;
     } @{$info->{args}};
     $args{args} = $dbargs;
@@ -276,6 +277,12 @@ Chris Travers,, C<< <chris.travers at gmail.com> >>
 
 =head1 BUGS
 
+Please report any bugs or feature requests to C<bug-pgobject-simple-role at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PGObject-Simple-Role>.  I will be notified, and then you'll
+Chris Travers,, C<< <chris.travers at gmail.com> >>
+
+=head1 BUGS
+
 Please report any bugs or feature requests to C<bug-pgobject-simple-role at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PGObject-Simple-Role>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
